import 'package:flutter/material.dart';
import 'package:editablegrid/models/grid-cell.dart';
import 'package:editablegrid/utils/validators.dart';
import 'package:editablegrid/editable-grid.dart';
import 'dialogs-builder.dart';

///Helper class that builds a wrapper around the grid.
class GridBuilder {
  ///Creates an Scaffold where the title is shown in the app bar and the grid gets centered within the body.
  static Scaffold buildGridWrap(
      {BuildContext context,
      String appBarTitle,
      EditableGridWidget grid,
      Function() editionCompletedCallback}) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: Text(
          appBarTitle,
          style: TextStyle(fontSize: 25),
        ),
        backgroundColor: Colors.blue,
      ),
      body: Center(
          child: ListView(
        padding: EdgeInsets.all(16),
        children: [
          grid,
          Divider(),
          FlatButton(
            child: Text(
              "Show raw data",
              style: TextStyle(color: Colors.white),
            ),
            onPressed: () {
              editionCompletedCallback();
            },
            color: Colors.blue,
          )
        ],
      )),
      backgroundColor: Colors.white,
    );
  }
}

///A set of cells with predefined values.
class CellsMock {
  Cell cellR1C1;
  Cell cellR1C2;
  Cell cellR1C3;
  Cell cellR2C1;
  Cell cellR2C2;
  Cell cellR2C3;

  CellsMock() {
    cellR1C1 = Cell(initialValue: "R1C1", validator: Validators.numbers);
    cellR1C2 = Cell(initialValue: "R1C2", validator: Validators.numbers);
    cellR1C3 = Cell(initialValue: "R1C3", validator: Validators.numbers);
    cellR2C1 = Cell(initialValue: "R2C1");
    cellR2C2 = Cell(initialValue: "R2C2");
    cellR2C3 = Cell(initialValue: "R2C3");
  }

  ///Shows the current value of each cell.
  void showData(BuildContext context) {
    DialogBuilder.buildAndShowDialog(
        context: context,
        title: "Raw table data:",
        content:
            "${cellR1C1.getValue()}-${cellR1C2.getValue()}-${cellR1C3.getValue()}\n" +
                "${cellR2C1.getValue()}-${cellR2C2.getValue()}-${cellR2C3.getValue()}",
        isError: false);
  }
}
